/*
 * Copyright 2021 IBM Corp.
 * SPDX-License-Identifier: Apache-2.0
 */
package io.xskipper.metadatastore.parquet.encryption

import io.xskipper.index.{BloomFilterIndex, MinMaxIndex, ValueListIndex}
import io.xskipper.metadatastore.parquet.ParquetMetadataStoreConf
import org.apache.spark.sql
import org.apache.spark.sql.types.{IntegerType, StringType, StructField}

object Values {

  val k1 = "iKwfmI5rDf7HwVBcqeNE6w== "
  val k2 = "LjxH/aXxMduX6IQcwQgOlw== "
  val k3 = "rnZHCxhUHr79Y6zvQnxSEQ=="
  val footerKeyLabel = "k1"
  val minMaxIdx = MinMaxIndex("temp", Some("k1"))
  val bloomFilterIdx = BloomFilterIndex("city", keyMetadata = Some("k1"))
  val valListIdx = ValueListIndex("city")

  val indexes = Seq(
    minMaxIdx,
    bloomFilterIdx,
    valListIdx
  )

  minMaxIdx.generateColsMap(Map("temp" -> ("temp", StructField("temp", IntegerType, true))))
  bloomFilterIdx.generateColsMap(Map("city" -> ("city", StructField("city", StringType, true))))
  valListIdx.generateColsMap(Map("city" -> ("city", StructField("city", StringType, true))))


  val tableIdentifier = "foo/bar"
  val columnKeyListStringEncryptedFooter =
    "k1:temp_minmax_4.min,temp_minmax_4.max,city_bloomfilter_4,obj_name"

  val columnKeyListStringPlaintextFooter =
    "k1:temp_minmax_4.min,temp_minmax_4.max,city_bloomfilter_4,obj_name"

  val columnKeyListStringEncryptedFooterV1 =
    "k1:temp_minmax.min,temp_minmax.max,city_bloomfilter,obj_name"

  val columnKeyListStringPlaintextFooterV1 =
    "k1:temp_minmax.min,temp_minmax.max,city_bloomfilter,obj_name"

  val encryptionMetaEncryptedFooter = new sql.types.MetadataBuilder()
    .putString(ParquetMetadataStoreConf.PARQUET_COLUMN_KEYS_SPARK_KEY,
      columnKeyListStringEncryptedFooter)
    .putString(ParquetMetadataStoreConf.PARQUET_FOOTER_KEY_SPARK_KEY, footerKeyLabel)
    .build()

  val encryptionMetaEncryptedFooterV1 = new sql.types.MetadataBuilder()
    .putString(ParquetMetadataStoreConf.PARQUET_COLUMN_KEYS_SPARK_KEY,
      columnKeyListStringEncryptedFooterV1)
    .putString(ParquetMetadataStoreConf.PARQUET_FOOTER_KEY_SPARK_KEY, footerKeyLabel)
    .build()

  val masterMetaEncryptedFooter = new sql.types.MetadataBuilder()
    .putMetadata("encryption", encryptionMetaEncryptedFooter)
    .putString("tableIdentifier", tableIdentifier)
    .putLong("version", ParquetMetadataStoreConf.PARQUET_MD_STORAGE_VERSION)
    .build()

  val masterMetaEncryptedFooterV1 = new sql.types.MetadataBuilder()
    .putMetadata("encryption", encryptionMetaEncryptedFooterV1)
    .putString("tableIdentifier", tableIdentifier)
    .putLong("version", 1L)
    .build()

  val encryptionMetaPlaintextFooter = new sql.types.MetadataBuilder()
    .putString(ParquetMetadataStoreConf.PARQUET_COLUMN_KEYS_SPARK_KEY,
      columnKeyListStringPlaintextFooter)
    .putString(ParquetMetadataStoreConf.PARQUET_PLAINTEXT_FOOTER_SPARK_KEY, "true")
    .putString(ParquetMetadataStoreConf.PARQUET_FOOTER_KEY_SPARK_KEY, footerKeyLabel)
    .build()

  val encryptionMetaPlaintextFooterV1 = new sql.types.MetadataBuilder()
    .putString(ParquetMetadataStoreConf.PARQUET_COLUMN_KEYS_SPARK_KEY,
      columnKeyListStringPlaintextFooterV1)
    .putString(ParquetMetadataStoreConf.PARQUET_PLAINTEXT_FOOTER_SPARK_KEY, "true")
    .putString(ParquetMetadataStoreConf.PARQUET_FOOTER_KEY_SPARK_KEY, footerKeyLabel)
    .build()

  val masterMetaPlaintextFooter = new sql.types.MetadataBuilder()
    .putMetadata("encryption", encryptionMetaPlaintextFooter)
    .putString("tableIdentifier", tableIdentifier)
    .putLong("version", ParquetMetadataStoreConf.PARQUET_MD_STORAGE_VERSION)
    .build()

  val masterMetaPlaintextFooterV1 = new sql.types.MetadataBuilder()
    .putMetadata("encryption", encryptionMetaPlaintextFooterV1)
    .putString("tableIdentifier", tableIdentifier)
    .putLong("version", 1L)
    .build()
}
